@@ -13,7 +13,6 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/utils/pointer"
 
-	osev1 "github.com/openshift/api/config/v1"
 	"github.com/openshift/cluster-version-operator/lib/resourceapply"
 )
 
@@ -63,26 +62,7 @@ func (optr *Operator) syncAll(config *OperatorConfig) error {
 }
 
 func (optr *Operator) syncClusterAPIController(config *OperatorConfig) error {
-	// Fetch the Feature
-	featureGate, err := optr.featureGateLister.Get(MachineAPIFeatureGateName)
-
-	var featureSet osev1.FeatureSet
-	if err != nil {
-		if !apierrors.IsNotFound(err) {
-			return err
-		}
-		glog.V(2).Infof("Failed to find feature gate %q, will use default feature set", MachineAPIFeatureGateName)
-		featureSet = osev1.Default
-	} else {
-		featureSet = featureGate.Spec.FeatureSet
-	}
-
-	features, err := generateFeatureMap(featureSet)
-	if err != nil {
-		return err
-	}
-
-	controller := newDeployment(config, features)
+	controller := newDeployment(config, nil)
 	_, updated, err := resourceapply.ApplyDeployment(optr.kubeClient.AppsV1(), controller)
 	if err != nil {
 		return err
@@ -94,6 +74,12 @@ func (optr *Operator) syncClusterAPIController(config *OperatorConfig) error {
 }
 
 func (optr *Operator) syncBaremetalControllers(config *OperatorConfig) error {
+	// First create a Secret needed for the Metal3 deployment
+	if err := createMariadbPasswordSecret(optr.kubeClient.CoreV1(), config); err != nil {
+		glog.Error("Not proceeding with Metal3 deployment. Failed to create Mariadb password.")
+		return err
+	}
+
 	metal3Deployment := newMetal3Deployment(config)
 	_, updated, err := resourceapply.ApplyDeployment(optr.kubeClient.AppsV1(), metal3Deployment)
 	if err != nil {
@@ -107,7 +93,8 @@ func (optr *Operator) syncBaremetalControllers(config *OperatorConfig) error {
 }
 
 func (optr *Operator) waitForDeploymentRollout(resource *appsv1.Deployment) error {
-	return wait.Poll(deploymentRolloutPollInterval, deploymentRolloutTimeout, func() (bool, error) {
+	var lastError error
+	err := wait.Poll(deploymentRolloutPollInterval, deploymentRolloutTimeout, func() (bool, error) {
 		d, err := optr.deployLister.Deployments(resource.Namespace).Get(resource.Name)
 		if apierrors.IsNotFound(err) {
 			return false, nil
@@ -115,20 +102,28 @@ func (optr *Operator) waitForDeploymentRollout(resource *appsv1.Deployment) erro
 		if err != nil {
 			// Do not return error here, as we could be updating the API Server itself, in which case we
 			// want to continue waiting.
-			glog.Errorf("Error getting Deployment %q during rollout: %v", resource.Name, err)
+			lastError = fmt.Errorf("getting Deployment %s during rollout: %v", resource.Name, err)
+			glog.Error(lastError)
 			return false, nil
 		}
 
 		if d.DeletionTimestamp != nil {
-			return false, fmt.Errorf("deployment %q is being deleted", resource.Name)
+			lastError = nil
+			return false, fmt.Errorf("deployment %s is being deleted", resource.Name)
 		}
 
 		if d.Generation <= d.Status.ObservedGeneration && d.Status.UpdatedReplicas == d.Status.Replicas && d.Status.UnavailableReplicas == 0 {
+			lastError = nil
 			return true, nil
 		}
-		glog.V(4).Infof("Deployment %q is not ready. status: (replicas: %d, updated: %d, ready: %d, unavailable: %d)", d.Name, d.Status.Replicas, d.Status.UpdatedReplicas, d.Status.ReadyReplicas, d.Status.UnavailableReplicas)
+		lastError = fmt.Errorf("deployment %s is not ready. status: (replicas: %d, updated: %d, ready: %d, unavailable: %d)", d.Name, d.Status.Replicas, d.Status.UpdatedReplicas, d.Status.ReadyReplicas, d.Status.UnavailableReplicas)
+		glog.V(4).Info(lastError)
 		return false, nil
 	})
+	if lastError != nil {
+		return lastError
+	}
+	return err
 }
 
 func newDeployment(config *OperatorConfig, features map[string]bool) *appsv1.Deployment {
@@ -139,6 +134,9 @@ func newDeployment(config *OperatorConfig, features map[string]bool) *appsv1.Dep
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "machine-api-controllers",
 			Namespace: config.TargetNamespace,
+			Annotations: map[string]string{
+				maoOwnedAnnotation: "",
+			},
 			Labels: map[string]string{
 				"api":     "clusterapi",
 				"k8s-app": "controller",
@@ -247,16 +245,13 @@ func newContainers(config *OperatorConfig, features map[string]bool) []corev1.Co
 			Args:      args,
 			Resources: resources,
 		},
-	}
-	// add machine-health-check controller container if it exists and enabled under feature gates
-	if enabled, ok := features[FeatureGateMachineHealthCheck]; ok && enabled {
-		containers = append(containers, corev1.Container{
+		{
 			Name:      "machine-healthcheck-controller",
 			Image:     config.Controllers.MachineHealthCheck,
 			Command:   []string{"/machine-healthcheck"},
 			Args:      args,
 			Resources: resources,
-		})
+		},
 	}
 	return containers
 }
